@@ -69,6 +69,7 @@ int main(int argc, char *argv[])
     parser.setApplicationDescription(description);
     aboutData.setupCommandLine(&parser);
     parser.addOption(QCommandLineOption(QStringLiteral("post-update"), i18n("Display release notes for the current Plasma release.")));
+    parser.addOption(QCommandLineOption(QStringLiteral("post-update-beta"), i18n("Display release notes for the current Plasma release, for beta versions.")));
     parser.addOption(QCommandLineOption(QStringLiteral("live-environment"), i18n("Display the live page intended for distro live environments.")));
 
     parser.process(app);
@@ -79,6 +80,8 @@ int main(int argc, char *argv[])
     auto controller = engine.singletonInstance<Controller *>("org.kde.plasma.welcome", "Controller");
     if (parser.isSet(QStringLiteral("post-update"))) {
         controller->setMode(Controller::Mode::Update);
+    } else if (parser.isSet(QStringLiteral("post-update-beta"))) {
+        controller->setMode(Controller::Mode::Beta);
     } else if (parser.isSet(QStringLiteral("live-environment"))) {
         controller->setMode(Controller::Mode::Live);
     }
